@@ -1,7 +1,7 @@
 package Catmandu::BagIt;
 
 use strict;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Catmandu::Sane;
 use Catmandu;
@@ -278,7 +278,7 @@ sub write {
     }
     else {
         $self->log->info("creating: $path");
-        mkdir $path;
+        mkpath($path);
         $self->_dirty($self->dirty | FLAG_BAGIT);
     }
 
@@ -1032,9 +1032,11 @@ sub _write_data {
     my @all_names_in_bag = ();
 
     foreach my $item ($self->list_files) {
+        my $filename = 'data/' . $item->{filename};
+        push @all_names_in_bag , $filename;
+
         next unless $item->flag & FLAG_DIRTY;
 
-        my $filename = 'data/' . $item->{filename};
         my $dir  = $filename; $dir =~ s/\/[^\/]+$//;
 
         $self->log->info("serializing $filename");
@@ -1061,8 +1063,6 @@ sub _write_data {
             write_text("$path/$filename", $item->data);
             $item->flag($item->flag ^ FLAG_DIRTY);
         }
-
-        push @all_names_in_bag , $filename;
     }
 
     # Check deleted files
@@ -1272,6 +1272,7 @@ Catmandu::BagIt - Low level Catmandu interface to the BagIt packages.
 # STATUS
 
 [![Build Status](https://travis-ci.org/LibreCat/Catmandu-BagIt.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-BagIt)
+[![Coverage Status](https://coveralls.io/repos/LibreCat/Catmandu-BagIt/badge.svg?branch=master&service=github)](https://coveralls.io/github/LibreCat/Catmandu-BagIt?branch=master)
 
 =end markdown
 
@@ -1316,7 +1317,7 @@ Catmandu::BagIt - Low level Catmandu interface to the BagIt packages.
     printf "files:\n";
     for my $file ($bagit->list_files) {
         my $stat = [$file->data->stat];
-        printf " name: %s\n", $file->name;
+        printf " name: %s\n", $file->filename;
         printf " size: %s\n", $stat->[7];
         printf " last-mod: %s\n", scalar(localtime($stat->[9]));
     }
